<?php

/* ************************************************************************* *\
		MULTISITE EVENT LOGGING
\* ************************************************************************* */

$suh_settings = suh_get_settings();

// user profile update 

add_action('profile_update','suh_user_profile_update' );

function suh_user_profile_update( $user_id ) {
	$userdata = get_userdata( $user_id );
	$message = 'User profile updated: '.print_r( $userdata, true );
	suh_log( $message, 2 );
}


// sending e-mail

if( $suh_settings['log_wp_mail'] ) {
	add_filter( 'wp_mail', 'suh_log_email' );
}

function suh_log_email( $mail_info ) {
	if( defined( 'WLS' ) && wls_is_registered( SUH_MAIL_LOGNAME ) ) {
		wls_simple_log( SUH_MAIL_LOGNAME, 'Sending an e-mail with subject "'.$mail_info['subject'].'"'."\n".'To: '.print_r( $mail_info['to'], true )."\n".' Headers: '.$mail_info['headers']."\n".'Message: '.$mail_info['message']."\n".'Attachments: '.$mail_info['attachments'], 1 );
	}
	return $mail_info;
}


// logging in

if( $suh_settings['log_wp_login'] ) {
	add_action( 'wp_login', 'suh_log_login' );
}

function suh_log_login( $username ) {
	suh_log( 'User '.$username.' logging in (IP '.suh_get_ip().').' );
}


// password resetting

add_action( 'lostpassword_post', 'suh_log_lostpassword_post' );

function suh_log_lostpassword_post() {
	suh_log( 'A password reset was requested.' );
	return;
}

add_action( 'password_reset', 'suh_log_password_reset' );

function suh_log_password_reset( $user ) {
	suh_log( 'User '.$user->user_login.' has reset it\'s password.', 2 );
}


// deleting an user

add_action( 'delete_user', 'suh_log_delete_user' );

function suh_log_delete_user( $user_id ) {
	suh_log( 'User ID='.$user_id.' was deleted.', 2 );
}


// uploading a file

add_action( 'add_attachment', 'suh_log_add_attachment' );

function suh_log_add_attachment( $id ) {
	$file = get_attached_file( $id );
	suh_log( 'File uploaded: "' . $file . '"', 2 );
}


// user logout

if( $suh_settings['log_wp_logout'] ) {
	add_action( 'wp_logout', 'suh_log_wp_logout' );
}

function suh_log_wp_logout( $user_login ) {
	suh_log( 'User '.$user_login.' has logged out.' );
}


// user registered

add_action( 'user_register', 'suh_log_user_register' );

function suh_log_user_register( $user_id ) {
	$userdata = get_userdata( $user_id );
	suh_log( 'User '.$userdata->user_login.' registered.', 2 );
}


// theme switch

add_action( 'switch_theme', 'suh_log_switch_theme' );

function suh_log_switch_theme( $theme ) {
	suh_log( 'Theme switched to '.$theme.'.', 2 );
}


// activate plugin

add_action( 'activated_plugin', 'suh_log_activate_plugin', 10, 2 );

function suh_log_activate_plugin( $plugin, $network_wide ) {
	if( $network_wide ) {
		suh_log( 'Plugin activated: "'.$plugin.'" network-wide.', 2 );
	} else {
		suh_log( 'Plugin activated: "'.$plugin.'".', 2 );
	}
}

// deactivate plugin

add_action( 'deactivated_plugin', 'suh_log_deactivate_plugin', 10, 2 );

function suh_log_deactivate_plugin( $plugin, $network_wide ) {
	if( $network_wide ) {
		suh_log( 'Plugin deactivated: "'.$plugin.'" network-wide.', 2 );
	} else {
		suh_log( 'Plugin deactivated: "'.$plugin.'".', 2 );
	}
}


// login errors

add_action( 'wp_login_failed', 'suh_log_login_error' );

function suh_log_login_error( $username ) {
	$user = get_userdatabylogin($username);
	$ip = suh_get_ip();
	if ( !$user || ($user->user_login != $username) ) {
		suh_log( 'Login failed: unknown user "' . $username . '" (IP '.$ip.')', 4 );
	} else {
		suh_log( 'Login failed: incorrect password for '.$username.' (IP '.$ip.').', 4 );
	}
}


// deactivate blog

add_action( 'deactivate_blog', 'suh_log_deactivate_blog' );

function suh_log_deactivate_blog( $blog_id ) {
	suh_log( 'Blog with id=='.$blog_id.' deactivated.', 2 );
}


// activate blog

add_action( 'activate_blog', 'suh_log_activate_blog' );

function suh_log_activate_blog( $blog_id ) {
	suh_log( 'Blog with id=='.$blog_id.' activated.', 2 );
}


// archive_blog

add_action( 'archive_blog', 'suh_log_archive_blog' );

function suh_log_archive_blog( $blog_id ) {
	suh_log( 'Blog with id=='.$blog_id.' archived.', 2 );
}


// unarchive_blog

add_action( 'unarchive_blog', 'suh_log_unarchive_blog' );

function suh_log_unarchive_blog( $blog_id ) {
	suh_log( 'Blog with id=='.$blog_id.' unarchived.', 2 );
}


// make_spam_blog

add_action( 'make_spam_blog', 'suh_log_make_spam_blog' );

function suh_log_make_spam_blog( $blog_id ) {
	suh_log( 'Blog with id=='.$blog_id.' marked as spam.', 2 );
}


// make_ham_blog

add_action( 'make_ham_blog', 'suh_log_make_ham_blog' );

function suh_log_make_ham_blog( $blog_id ) {
	suh_log( 'Blog with id=='.$blog_id.' marked as ham.', 2 );
}


// mature_blog

add_action( 'mature_blog', 'suh_log_mature_blog' );

function suh_log_mature_blog( $blog_id ) {
	suh_log( 'Blog with id=='.$blog_id.' marked as mature.', 2 );
}

// unmature_blog

add_action( 'unmature_blog', 'suh_log_unmature_blog' );

function suh_log_unmature_blog( $blog_id ) {
	suh_log( 'Removed "mature" mark from blog with id=='.$blog_id.'.', 2 );
}


// delete blog

add_action( 'delete_blog', 'suh_log_delete_blog', 10, 2 );

function suh_log_delete_blog( $blog_id, $drop ) {
	$msg = 'Deleting blog with id=='.$blog_id;
	if( $drop ) {
		$msg.= ' (dropping from database)';
	}
	$msg.= '.';
	suh_log( $msg, 3 );
}


// add user to blog

add_action( 'add_user_to_blog', 'suh_log_add_user_to_blog', 10, 3 );

function suh_log_add_user_to_blog( $user_id, $role, $blog_id ) {
	$userdata = get_userdata( $user_id );
	$blog_details = get_blog_details( $blog_id, true );
	suh_log( 'User '.$userdata->user_login.' (ID=='.$user_id.') added to blog '.$blog_details->blogname.' ('.$blog_details->domain.', ID=='.$blog_details->blog_id.') with role '.$role.'.', 2 );
}


// remove user from blog

add_action( 'remove_user_from_blog', 'suh_log_remove_user_from_blog', 10, 2 );

function suh_log_remove_user_from_blog( $user_id, $blog_id ) {
	$userdata = get_userdata( $user_id );
	$blog_details = get_blog_details( $blog_id, true );
	suh_log( 'User '.$userdata->user_login.' (ID=='.$user_id.') removed from blog '.$blog_details->blogname.' ('.$blog_details->domain.', ID=='.$blog_details->blog_id.').', 3 );
}


// update_plugin_complete_actions

add_filter( 'update_plugin_complete_actions', 'suh_log_update_plugin_complete_actions', 10, 2 );

function suh_log_update_plugin_complete_actions( $update_actions, $plugin ) {
	suh_log( 'Upgrading plugin "'.$plugin.'".', 3 );
	return $update_actions;
}


// install_plugin_complete_actions

add_filter( 'install_plugin_complete_actions', 'suh_log_install_plugin_complete_actions', 10, 3 );

function suh_log_install_plugin_complete_actions( $install_actions, $api, $plugin_file ) {
	suh_log( 'Installing plugin "'.$plugin_file.'".', 3 );
	return $install_actions;
}


// update_theme_complete_actions

add_filter( 'update_theme_complete_actions', 'suh_log_update_theme_complete_actions', 10, 2 );

function update_theme_complete_actions( $update_actions, $theme ) {
	suh_log( 'Upgrading theme "'.$theme.'".', 3 );
	return $update_actions;
}


// install_theme_complete_actions

add_filter( 'install_theme_complete_actions', 'suh_log_install_theme_complete_actions', 10, 4 );

function suh_log_install_theme_complete_actions( $install_actions, $api, $stylesheet, $theme_file ) {
	suh_log( 'Installing theme "'.$theme_file.'".', 3 );
	return $install_actions;
}


// blog_redirect_404
if( $suh_settings['log_blog_redirect_404'] ) {
	add_filter( 'blog_redirect_404', 'suh_log_blog_redirect_404' );
}

function suh_log_blog_redirect_404( $redirect ) {
	suh_log( 'Requested a non-available page "'.$_SERVER['REQUEST_URI'].'", redirecting to "'.$redirect.'".', 1 );
	return $redirect;
}


?>
