<?php

/*****************************************************************************\
		BAD LOGIN PERMBAN
\*****************************************************************************/


function suh_check_permban_ready() {
	$settings = suh_get_settings();
	if( !$settings['permban_ready'] ) {
		global $wpdb;
		$query = 'CREATE TABLE IF NOT EXISTS '.suh_permban_table().' (
            id INT NOT NULL AUTO_INCREMENT,
            ip VARCHAR( 63 ) UNIQUE,
            attempt_count INT DEFAULT 0,
            last_attempt DATETIME,
            PRIMARY KEY ( id )
        )';
        $ok = $wpdb->query( $query );
        if( $ok ) {
        	suh_log( 'Successfully created permban table.', 2 );
        	$settings['permban_ready'] = true;
        	suh_update_settings( $settings );
        } else {
        	suh_log( 'Error while creating permban table.', 5 );
        }
	}
}


function suh_permban_table() {
	global $wpdb;
	return $wpdb->base_prefix.'suh_permban';
}


function suh_is_permban_active() {
	extract( suh_get_settings() );
	return $is_permban_active;
}


function suh_add_permban( $ip ) {
	suh_check_permban_ready();
	global $wpdb;
	$inserted = $wpdb->query( $wpdb->prepare( 'INSERT IGNORE INTO '.suh_permban_table().' (ip) VALUE (%s)', $ip ) );
	if( $inserted == false ) {
		suh_log( 'Error while creating permban for IP '.$ip.'.', 4 );
	} else {
		suh_log( 'Permban for IP '.$ip.' successfully created.', 3 );
	}
}


function suh_get_permbans() {
	global $wpdb;
	return $wpdb->get_results( 'SELECT * FROM '.suh_permban_table() );
}


function suh_is_banned( $ip ) {
	global $wpdb;
	return ( $wpdb->get_var( $wpdb->prepare( 'SELECT COUNT(1) FROM '.suh_permban_table().' WHERE ip = %s', $ip ) ) > 0 );
}


function suh_remove_permban( $id ) {
	global $wpdb;
	return !( $wpdb->query( $wpdb->prepare( 'DELETE FROM '.suh_permban_table().' WHERE id = %d', $id ) ) === FALSE );
}


add_action( 'wp_login_failed', 'suh_maybe_permban' );

function suh_maybe_permban( $username ) {
	extract( suh_get_settings() );
	if( $is_permban_active ) {
		$user = get_userdatabylogin( $username );
		$ip = suh_get_ip();
		if ( !$user || ( $user->user_login != $username ) ) {
			$forbidden_logins = explode( ',', $forbidden_logins );
			if( in_array( $username, $forbidden_logins ) ) { // TODO jména ze seznamu
				suh_add_permban( $ip );
			}
		}
	}
}


add_action( 'init', 'suh_ban_check' );


function suh_ban_check() {
	$ip = suh_get_ip();
	if( !is_user_logged_in() && suh_is_banned( $ip ) ) {
		extract( suh_get_settings() );
		if( $log_banned_attempt ) {
			suh_log( 'Attempt to access from banned IP '.$ip.'.', 1 );
			suh_increment_attempt_count( $ip );
		}
		
		echo $banned_message;
		exit();
	}
}


function suh_increment_attempt_count( $ip ) {
	$lock_name = "suh_increment_attempt_count($ip)";
	global $wpdb;
	$locked = $wpdb->get_var( 'SELECT GET_LOCK(\''.$lock_name.'\', 0)' );
	if( $locked != '1' ) {
		return;
	}
	$wpdb->query( $wpdb->prepare( "UPDATE ".suh_permban_table()." SET attempt_count = attempt_count + 1, last_attempt = NOW() WHERE ip LIKE %s", $ip ) );
	$wpdb->query( 'SELECT RELEASE_LOCK(\''.$lock_name.'\')' );
}


add_action( 'network_admin_menu','suh_network_permban_menu' );

function suh_network_permban_menu() {
	add_submenu_page( 'users.php', __( 'Permban', SUH_TEXTDOMAIN ), __( 'Permban', SUH_TEXTDOMAIN ), 'manage_network_users', 
		'suh-permban', 'suh_permban_page' );
}

add_action( 'admin_menu','suh_permban_menu' );

function suh_permban_menu() {
	if( !is_multisite() ) {
		add_submenu_page( 'users.php', __( 'Permban', SUH_TEXTDOMAIN ), __( 'Permban', SUH_TEXTDOMAIN ), 'manage_users', 
		'suh-permban', 'suh_permban_page' );
	}
}


function suh_permban_page() {
	if( isset($_REQUEST['action']) ) {
        $action = $_REQUEST['action'];
    } else {
        $action = 'default';
    }
    
    switch( $action ) {
    case 'remove_permban':
    	suh_remove_permban( $_GET['id'] );
    	suh_permban_page_default();
    	break;
    default:
		suh_permban_page_default();
		break;
	}
}


function suh_get_possible_comment_authors( $ip ) {
	global $wpdb;
	$blog_query = 'SELECT blog_id FROM '.$wpdb->base_prefix.'blogs';
	$blog_list = $wpdb->get_col( $wpdb->prepare( $blog_query ) );
	$comment_subqueries = array();
	foreach( $blog_list as $blog_id ) { //\''.$blog_id.'\' AS blog_id
		$comment_subqueries[] = $wpdb->prepare( 
			'SELECT comment_author, comment_author_email, comment_author_url, comment_ID, comment_post_ID 
			FROM '.$wpdb->base_prefix.$blog_id.'_comments 
			WHERE comment_author_IP = %s', 
			$ip
		);
	}
	$comment_query = '( '.implode( ' ) UNION ( ', $comment_subqueries ).' )';
	$comments = $wpdb->get_results( $comment_query );
	return $comments;
}


function suh_permban_page_default() {
	$permbans = suh_get_permbans();
	?>
	<div id="wrap">
		<h2><?php _e( 'Permban', SUH_TEXTDOMAIN ); ?></h2>
		<table class="widefat" cellspacing="0">
		    <thead>
		        <tr>
		            <th scope="col" class="manage-column">id<br /><?php _e( 'Action', SUH_TEXTDOMAIN ); ?></th>
		            <th scope="col" class="manage-column"><?php _e( 'IP address', SUH_TEXTDOMAIN ); ?></th>
		            <th scope="col" class="manage-column"><?php _e( 'Notes', SUH_TEXTDOMAIN ); ?></th>
				</tr>
			</thead>
		    <tfoot>
		        <tr>
		            <th scope="col" class="manage-column">id<br /><?php _e( 'Action', SUH_TEXTDOMAIN ); ?></th>
		            <th scope="col" class="manage-column"><?php _e( 'IP address', SUH_TEXTDOMAIN ); ?></th>
		            <th scope="col" class="manage-column"><?php _e( 'Notes', SUH_TEXTDOMAIN ); ?></th>
				</tr>
			</tfoot>
			<?php
				foreach( $permbans as $permban ) {
					?>
					<tr>
						<td>
							<?php echo $permban->id; ?><br />
							<a href="<?php echo suh_get_pagenow(); ?>&action=remove-permban&id=<?php echo $permban->id; ?>">&times;</a>
						</td>
						<td><strong><?php echo $permban->ip; ?></strong></td>
						<td>
							<p>
								<?php 
									printf( __( "There have been %s attempts to access site from this IP since it was banned.", SUH_TEXTDOMAIN ),
										$permban->attempt_count
									);
									if( $permban->attempt_count > 0 ) {
										echo " ";
										printf( __( "Last one occured at %s.", SUH_TEXTDOMAIN ), $permban->last_attempt );
									}
								?>
							</p>
							<?php
								$origins = array();
								$comments = suh_get_possible_comment_authors( $permban->ip );
								if( !empty( $comments ) ) {
									_e( 'Possible origins of attack / affected visitors', SUH_TEXTDOMAIN ); /*'Možní původci útoku nebo postižení návštěvníci:<br />';*/
									$authors = array();
									foreach( $comments as $comment ) {
										$author = $comment->comment_author;
										if( !empty( $comment->comment_author_url ) ) {
											$author = '<a href="'.$comment->comment_author_url.'">'.$author.'</a>';
										}
										$author.= ' (<a href="mailto:'.$comment->comment_author_email.'">'.$comment->comment_author_email.'</a>)';
										//$author.= ' <a href="'.get_blog_option( $comment->blog_id, 'siteurl' ).'?p='.$comment->comment_post_ID.'#comment-'.$comment->comment_ID.'" target="_blank">'.__( 'comment', SUH_TEXTDOMAIN ).'</a>';
										
										//comment_ID, comment_post_ID, \''.$blog_id.'\' AS blog_id
										
										$authors[] = $author;
									}
									$origins[] = implode( ', ', $authors );
								}
								if( defined( 'WLS' ) && function_exists( 'wls_entries_table' ) ) {
									global $wpdb;
									$log_entries = $wpdb->get_results( $wpdb->prepare( 
										'SELECT id, text FROM '.wls_entries_table().' WHERE ( 
											text LIKE %s 
											AND text NOT LIKE %s
											AND text NOT LIKE %s
										)', 
										'%'.$permban->ip.'%', 
										'%Attempt to access from banned IP%',
										'%Permban for % successfully created%'
									) );
									$entries = array();
									foreach( $log_entries as $log_entry ) {
										$log_text = strlen( $log_entry->text ) > 150 ? substr( $log_entry->text, 0, 150 )."..." : $log_entry->text;
										$entries[] = sprintf( 
											'<tr style="border:none;">
												<td style="border:none;"><small><code>%d</code>: %s</small></td>
												<td style="border:none;">
													<form 
														method="post" action="index.php?page=wls-superadmin-overview" target="_blank"
													>
														<input type="hidden" name="entry_id" value="%s">
														<input type="submit" value="&raquo;">
													</form>
												</td>
											</tr>', 
											$log_entry->id, $log_text, $log_entry->id 
										);
									}
									if( !empty( $entries ) ) {
										$origins[] = 'WLS log entries concerning this IP address:<table style="border:none;">'.implode( '', $entries ).'</table>';
									}
								}
								if( !empty( $origins ) ) {
									echo '<p>'.implode( '</p><p>', $origins ).'</p>';
								} else {
									_e( 'Unknown attack origin.', SUH_TEXTDOMAIN );
								}
							?>
						</td>
					</tr>
					<?php
				}
			?>
	</div>
	<?php
}

?>
